diff Core/SQLite/StatementReference.cpp @ 59:c996319e90bc orthanc-renaming

renaming in Core
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:28:56 +0200
parents a15e90e5d6fc
children bdd72233b105
line wrap: on
line diff
--- a/Core/SQLite/StatementReference.cpp	Sun Sep 16 09:24:13 2012 +0200
+++ b/Core/SQLite/StatementReference.cpp	Sun Sep 16 09:28:56 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -36,12 +36,12 @@
 
 #include "StatementReference.h"
 
-#include "../PalanthirException.h"
+#include "../OrthancException.h"
 
 #include <cassert>
 #include "sqlite3.h"
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace SQLite
   {
@@ -63,7 +63,7 @@
     {
       if (database == NULL || sql == NULL)
       {
-        throw PalanthirException(ErrorCode_ParameterOutOfRange);
+        throw OrthancException(ErrorCode_ParameterOutOfRange);
       }
 
       root_ = NULL;
@@ -72,7 +72,7 @@
       int error = sqlite3_prepare_v2(database, sql, -1, &statement_, NULL);
       if (error != SQLITE_OK)
       {
-        throw PalanthirException("SQLite: " + std::string(sqlite3_errmsg(database)));
+        throw OrthancException("SQLite: " + std::string(sqlite3_errmsg(database)));
       }
 
       assert(IsRoot());
@@ -104,7 +104,7 @@
         if (refCount_ != 0)
         {
           // There remain references to this object
-          throw PalanthirException(ErrorCode_InternalError);
+          throw OrthancException(ErrorCode_InternalError);
         }
         else if (statement_ != NULL)
         {
@@ -115,7 +115,7 @@
       {
         if (root_->refCount_ == 0)
         {
-          throw PalanthirException(ErrorCode_InternalError);
+          throw OrthancException(ErrorCode_InternalError);
         }
         else
         {
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium